Package: geeLite
Type: Package
Title: Building and Managing Local Databases from 'Google Earth Engine'
Version: 1.0.6
Authors@R: c(
  person("Marcell T.", "Kurbucz", email = "m.kurbucz@ucl.ac.uk", role = c("aut", "cre")),
  person("Bo Pieter Johannes", "Andrée", email = "bandree@worldbank.org", role = "aut"))
Description: Simplifies the creation, management, and updating of local databases using data extracted from 'Google Earth Engine' ('GEE'). It integrates with 'GEE' to store, aggregate, and process spatio-temporal data, leveraging 'SQLite' for efficient, serverless storage. The 'geeLite' package provides utilities for data transformation and supports real-time monitoring and analysis of geospatial features, making it suitable for researchers and practitioners in geospatial science. For details, see Kurbucz and Andrée (2025) "Building and Managing Local Databases from Google Earth Engine with the geeLite R Package" <https://hdl.handle.net/10986/43165>.
License: MPL-2.0
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Imports: rnaturalearthdata, rnaturalearth, googledrive, data.table,
        reticulate, rstudioapi, geojsonio, lubridate, jsonlite,
        magrittr, progress, reshape2, RSQLite, stringr, crayon, dplyr,
        h3jsr, knitr, utils, purrr, stats, tidyr, rgee, cli, sf
Suggests: testthat (>= 3.0.0), rmarkdown, optparse, leaflet, withr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-12-11 14:47:11 UTC; mtkurbucz
Author: Marcell T. Kurbucz [aut, cre],
  Bo Pieter Johannes Andrée [aut]
Maintainer: Marcell T. Kurbucz <m.kurbucz@ucl.ac.uk>
Repository: CRAN
Date/Publication: 2025-12-11 23:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:30:27 UTC; unix
