# Generated by roxygen2: do not edit by hand

export(fetch_regions)
export(fetch_vars)
export(gee_install)
export(get_config)
export(get_state)
export(init_postp)
export(modify_config)
export(read_db)
export(run_geelite)
export(set_cli)
export(set_config)
import(rgee)
import(rnaturalearthdata)
importFrom(RSQLite,SQLite)
importFrom(RSQLite,dbConnect)
importFrom(RSQLite,dbDisconnect)
importFrom(RSQLite,dbListTables)
importFrom(RSQLite,dbReadTable)
importFrom(RSQLite,dbRemoveTable)
importFrom(RSQLite,dbWriteTable)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_h1)
importFrom(cli,rule)
importFrom(crayon,blue)
importFrom(crayon,green)
importFrom(data.table,fread)
importFrom(data.table,rbindlist)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_all)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(geojsonio,geojson_list)
importFrom(googledrive,as_id)
importFrom(googledrive,drive_auth)
importFrom(googledrive,drive_find)
importFrom(googledrive,drive_ls)
importFrom(googledrive,drive_rm)
importFrom(googledrive,drive_user)
importFrom(h3jsr,cell_to_polygon)
importFrom(h3jsr,polygon_to_cells)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,write_json)
importFrom(knitr,kable)
importFrom(lubridate,floor_date)
importFrom(lubridate,ymd)
importFrom(magrittr,"%>%")
importFrom(progress,progress_bar)
importFrom(purrr,map)
importFrom(purrr,modify_in)
importFrom(reshape2,dcast)
importFrom(reshape2,melt)
importFrom(reticulate,conda_binary)
importFrom(reticulate,conda_create)
importFrom(reticulate,conda_list)
importFrom(reticulate,conda_python)
importFrom(reticulate,conda_remove)
importFrom(reticulate,import)
importFrom(reticulate,install_miniconda)
importFrom(reticulate,py_config)
importFrom(reticulate,py_install)
importFrom(reticulate,use_condaenv)
importFrom(rgee,ee_Authenticate)
importFrom(rgee,ee_check_credentials)
importFrom(rgee,ee_drive_to_local)
importFrom(rgee,ee_extract)
importFrom(rgee,ee_install_set_pyenv)
importFrom(rgee,ee_monitoring)
importFrom(rgee,ee_table_to_drive)
importFrom(rgee,sf_as_ee)
importFrom(rnaturalearth,ne_countries)
importFrom(rnaturalearth,ne_states)
importFrom(rstudioapi,isAvailable)
importFrom(rstudioapi,restartSession)
importFrom(sf,st_as_sf)
importFrom(sf,st_crs)
importFrom(sf,st_geometry)
importFrom(sf,st_read)
importFrom(sf,st_set_crs)
importFrom(sf,st_set_geometry)
importFrom(sf,st_write)
importFrom(stats,approx)
importFrom(stats,na.omit)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stringr,str_detect)
importFrom(stringr,str_sub)
importFrom(tidyr,all_of)
importFrom(tidyr,complete)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(utils,flush.console)
importFrom(utils,getFromNamespace)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
importFrom(utils,old.packages)
importFrom(utils,packageVersion)
